@@ -11,7 +11,7 @@ an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express o
 specific language governing permissions and limitations under the License.
 """
 from bamboo_engine.eri import NodeType
-from .base import *  # noqa
+from .base import Element
 
 __all__ = ["EmptyEndEvent", "EmptyStartEvent", "ExecutableEndEvent"]
 
